# Package with miscelaneous utils

## 1 password

```python
creds = op.get_item("pypi.org", ["username", "password"])
# use `creds.username` or `creds.password`
```

## PyPI

https://pypi.org/project/maxhk/
